@@ -67,6 +67,9 @@ void background_init(void);
 void background_properties_init(void);
 void background_read(struct bgState *state);
 void background_setup(struct bgState *state);
+void printState(struct bgState *state);
+void copyState(struct bgState *dest, struct bgState *src);
+void background_ok(GtkWidget *widget, struct bgState *state);
 
 
 void
@@ -175,6 +178,7 @@ fill_monitor (int prop_changed, struct bgState *state)
     GC xgc;
     unsigned char *pdata;
     gint rootWidth, rootHeight;
+    gushort short_r, short_g, short_b, short_a;
     gint r, g, b, a;
     gint cx, cy;
     gint cw, ch;
@@ -208,7 +212,12 @@ fill_monitor (int prop_changed, struct bgState *state)
     }
     
     if (capplet) {
-	gnome_color_picker_get_i16(GNOME_COLOR_PICKER(cp1), &r, &g, &b, &a);
+	gnome_color_picker_get_i16(GNOME_COLOR_PICKER(cp1), &short_r, &short_g, &short_b, &short_a);
+    r = short_r;
+    g = short_g;
+    b = short_b;
+    a = short_a;
+
 	state->bgColor1.red = r;
 	state->bgColor1.green = g;
 	state->bgColor1.blue = b;
@@ -217,7 +226,12 @@ fill_monitor (int prop_changed, struct bgState *state)
 	b >>= 8;
 	state->bgColor1.pixel = gdk_imlib_best_color_match(&r, &g, &b);
 
-	gnome_color_picker_get_i16(GNOME_COLOR_PICKER(cp2),  &r, &g, &b, &a);
+	gnome_color_picker_get_i16(GNOME_COLOR_PICKER(cp2), &short_r, &short_g, &short_b, &short_a);
+    r = short_r;
+    g = short_g;
+    b = short_b;
+    a = short_a;
+    
 	state->bgColor2.red = r;
 	state->bgColor2.green = g;
 	state->bgColor2.blue = b;
@@ -1051,7 +1065,7 @@ background_read ( struct bgState *state )
 	gint r, g, b;
 
 	gdk_color_parse
-		(gnome_config_get_string ("/Background/Default/color1=#808080"),
+		(gnome_config_get_string ("/Background/Default/color1=#005060"),
 		 &state->bgColor1);
 	r = state->bgColor1.red >> 8;
 	g = state->bgColor1.green >> 8;
