@@ -213,49 +213,56 @@ int
 main (int argc, char **argv)
 {
         GnomeClient *client = NULL;
+        GnomeClientFlags flags;
         gchar *session_args[2];
-        int token;
+        int token, init_results;
 
         bindtextdomain (PACKAGE, GNOMELOCALEDIR);
         textdomain (PACKAGE);
 
-        client = gnome_master_client ();
-
-        if(client) {
-                session_args[0] = argv[0];
-                session_args[1] = "--init-session-settings";
-                session_args[2] = NULL;
-                gnome_client_set_restart_style (client, GNOME_RESTART_ANYWAY);
-                gnome_client_set_restart_command (client, 2, session_args);
-                gnome_client_flush(client);
-        }
-
-        switch (gnome_capplet_init ("bell-properties", VERSION, argc,
-                                    argv, NULL, 0, NULL)) {
-                
-        case -1:
-                g_warning ("an initialization error occurred while starting 'mouse-properties-capplet'.\n"
+	init_results = gnome_capplet_init("bell-properties", VERSION,
+					  argc, argv, NULL, 0, NULL);
+	if (init_results < 0) {
+                g_warning ("an initialization error occurred while "
+			   "starting 'bell-properties-capplet'.\n"
                            "aborting...\n");
-                return 1;
-        case 1:
-                /* session initialization */
-                if(client && gnome_client_get_previous_id(client)) {
-                        token = gnome_startup_acquire_token("GNOME_BELL_PROPERTIES",
-                                                            gnome_client_get_id(client));
-                } else
-                        token = 1;
-            
-                if(token) {
-                        bell_read ();
-                        bell_apply ();
-                }
-                return 0;
-        default:
+                exit (1);
+	}
+
+	client = gnome_master_client ();
+	flags = gnome_client_get_flags(client);
+
+	if (flags & GNOME_CLIENT_IS_CONNECTED) {
+		token = gnome_startup_acquire_token("GNOME_BELL_PROPERTIES",
+				                  gnome_client_get_id(client));
+
+		if (token) {
+			session_args[0] = argv[0];
+			session_args[1] = "--init-session-settings";
+			session_args[2] = NULL;
+			gnome_client_set_priority (client, 20);
+			gnome_client_set_restart_style (client, 
+							GNOME_RESTART_ANYWAY);
+			gnome_client_set_restart_command (client, 2, 
+							  session_args);
+		}
+		else 
+			gnome_client_set_restart_style (client, 
+							GNOME_RESTART_NEVER);
+
+                gnome_client_flush (client);
         }
+	else
+		token = 1;
 
-        bell_read ();
-        bell_setup ();
-        capplet_gtk_main ();
+        bell_read ();	
 
+        if(token) 
+                bell_apply ();
+
+	if (init_results != 1) {
+		bell_setup ();
+	        capplet_gtk_main ();
+	}
 	return 0;
 }
