@@ -26,10 +26,17 @@ EditorDescription original_info;
 EditorDescription possible_editors[] =
 {
         { "Emacs", "emacs", FALSE, "executable", TRUE },
+        { "XEmacs", "xemacs", FALSE, "executable", TRUE },
         { "vi", "vi", TRUE, "executable", TRUE },
         { "Go", "go", FALSE, "executable", FALSE },
         { "gEdit", "gedit", FALSE, "executable", FALSE },
-        { "GWP", "gwp", FALSE, "executable", FALSE }
+        { "GWP", "gwp", FALSE, "executable", FALSE },
+        { "Jed", "jed", TRUE, "executable", TRUE },
+        { "Joe", "joe", TRUE, "executable", TRUE },
+        { "Pico", "pico", TRUE, "executable", TRUE },
+        { "vim",  "vim", TRUE, "executable", TRUE },
+        { "gvim",  "gvim", FALSE, "executable", TRUE },
+        { "ed", "ed", TRUE, "executable", FALSE },
 };
 
 static GtkWidget *capplet;
