@@ -302,10 +302,11 @@ mouse_setup (void)
         gtk_widget_show_all (capplet);
 }
 
-void
+int
 main (int argc, char **argv)
 {
         GnomeClient *client = NULL;
+        GnomeClientFlags flags;
         gchar *session_args[2];
         int token, init_results;
 
@@ -315,38 +316,47 @@ main (int argc, char **argv)
         init_results = gnome_capplet_init("mouse-properties", VERSION,
                                           argc, argv, NULL, 0, NULL);
 
-        client = gnome_master_client ();
-        if(client) {
-                session_args[0] = argv[0];
-                session_args[1] = "--init-session-settings";
-                session_args[2] = NULL;
-                gnome_client_set_restart_style (client, GNOME_RESTART_ANYWAY);
-                gnome_client_set_restart_command (client, 2, session_args);
-                gnome_client_flush(client);
-        }
-        
-        switch (init_results) {
-        case -1:
-                g_warning ("an initialization error occurred while starting 'mouse-properties-capplet'.\n"
+	if (init_results < 0) {
+                g_warning ("an initialization error occurred while "
+			   "starting 'mouse-properties-capplet'.\n"
                            "aborting...\n");
                 exit (1);
-        case 1:
-                /* session initialization */
-                if(client && gnome_client_get_previous_id(client)) {
-                        token = gnome_startup_acquire_token("GNOME_MOUSE_PROPERTIES",
-                                                            gnome_client_get_id(client));
-                } else
-                        token = 1;
+	}
 
-                if(token) {
-                        mouse_read ();
-                        mouse_apply ();
-                }
-                return 0;
-        default:
+	client = gnome_master_client ();
+	flags = gnome_client_get_flags(client);
+
+	if (flags & GNOME_CLIENT_IS_CONNECTED) {
+		token = gnome_startup_acquire_token("GNOME_MOUSE_PROPERTIES",
+				                  gnome_client_get_id(client));
+
+		if (token) {
+			session_args[0] = argv[0];
+			session_args[1] = "--init-session-settings";
+			session_args[2] = NULL;
+			gnome_client_set_priority (client, 20);
+			gnome_client_set_restart_style (client, 
+							GNOME_RESTART_ANYWAY);
+			gnome_client_set_restart_command (client, 2, 
+							  session_args);
+		}
+		else 
+			gnome_client_set_restart_style (client, 
+							GNOME_RESTART_NEVER);
+
+                gnome_client_flush (client);
         }
+	else
+		token = 1;
 
-        mouse_read ();
-        mouse_setup();
-        capplet_gtk_main ();
+        mouse_read ();	
+
+        if(token) 
+                mouse_apply ();
+
+	if (init_results != 1) {
+		mouse_setup ();
+	        capplet_gtk_main ();
+	}
+        return 0;
 }
