@@ -12,7 +12,6 @@
 #include <dirent.h>
 #include <gtk/gtk.h>
 #include "capplet-widget.h"
-
 #include <gnome.h>
 
 typedef struct {
@@ -29,6 +28,12 @@ typedef struct {
     gint ignore_changed;
 } SoundProps;
 
+static SoundProps *sound_properties_create(void);
+
+#ifdef HAVE_ESD
+
+#include <esd.h>
+
 typedef struct {
     gchar *category;
     gchar *name;
@@ -37,7 +42,6 @@ typedef struct {
 } SoundEvent;
 
 static void sound_properties_regenerate_ctree(SoundProps *props);
-static SoundProps *sound_properties_create(void);
 static void sound_properties_event_free(SoundEvent *ev);
 static void sound_properties_read_path(SoundProps *props,
                                        GString *tmpstr,
@@ -58,6 +62,7 @@ static void ui_do_cancel(GtkWidget *w, SoundProps *props);
 static void sound_properties_play_sound(GtkWidget *btn, SoundProps *props); 
 static void reload_esd_samples(const char *config_path);
 static void reload_all_esd_samples(void);
+#endif
 
 int
 main(int argc, char *argv[])
@@ -68,22 +73,24 @@ main(int argc, char *argv[])
     int token, init_results;
     SoundProps *sound_properties;
 
-	init_results = gnome_capplet_init("sound-properties", VERSION,
-					  argc, argv, NULL, 0, NULL);
+    init_results = gnome_capplet_init("sound-properties", VERSION,
+                                      argc, argv, NULL, 0, NULL);
 
-	if (init_results < 0) {
-                g_warning ("an initialization error occurred while "
-                           "starting 'sound-properties-capplet'.\n"
-                           "aborting...\n");
-                exit (1);
-	}
+    if (init_results < 0)
+        g_error ("an initialization error occurred while "
+                 "starting 'sound-properties-capplet'.");
 
-	client = gnome_master_client ();
-	flags = gnome_client_get_flags(client);
+    client = gnome_master_client ();
+
+    if(client)
+        flags = gnome_client_get_flags(client);
+    else
+        flags = 0;
 
 	if (flags & GNOME_CLIENT_IS_CONNECTED) {
+#ifdef HAVE_ESD
 		token = gnome_startup_acquire_token("GNOME_SOUND_PROPERTIES",
-				                  gnome_client_get_id(client));
+                                            gnome_client_get_id(client));
 
 		if (token) {
 			session_args[0] = argv[0];
@@ -91,30 +98,53 @@ main(int argc, char *argv[])
 			session_args[2] = NULL;
 			gnome_client_set_priority (client, 20);
 			gnome_client_set_restart_style (client, 
-							GNOME_RESTART_ANYWAY);
+                                            GNOME_RESTART_ANYWAY);
 			gnome_client_set_restart_command (client, 2, 
-							  session_args);
+                                              session_args);
 		}
-		else 
+		else
+#endif
 			gnome_client_set_restart_style (client, 
-							GNOME_RESTART_NEVER);
+                                            GNOME_RESTART_NEVER);
 
         gnome_client_flush (client);
-        }
-	else
+    } else
 		token = 1;
 
-    /* gnome-session now manages the starting and stopping of esd. */
+    switch(init_results) {
+    case 1:
+#ifdef HAVE_ESD
+        if(token) {
+            if(gnome_sound_connection < 0
+               && gnome_config_get_bool("/sound/system/settings/start_esd=true")) {
+                int esdpid;
+                static const char *esd_cmdline[] = {"esd", NULL};
+                char *tmpargv[3];
+                char argbuf[32];
+                
+                esdpid = gnome_execute_async(NULL, 1, (char **)esd_cmdline);
+                g_snprintf(argbuf, sizeof(argbuf), "%d", esdpid);
+                tmpargv[0] = "kill"; tmpargv[1] = argbuf; tmpargv[2] = NULL;
+                gnome_client_set_shutdown_command(client, 2, tmpargv);
+                sleep(1); /* lame... */
+                gnome_sound_init(NULL);
+            }
+            
+            if(gnome_sound_connection >= 0
+               && gnome_config_get_bool("/sound/system/settings/event_sounds=true"))
+                reload_all_esd_samples();
+        }
+#endif
+        break;
 
-    if(token && gnome_sound_connection >= 0) {
-        if (gnome_config_get_bool("/sound/system/settings/event_sounds=true"))
-            reload_all_esd_samples();
-    }
-
-	if (init_results != 1) {
+    case 0:
         sound_properties = sound_properties_create();
         capplet_gtk_main ();
-	}
+
+    default:
+        break;
+    }
+
     return 0;
 }
 
@@ -124,7 +154,6 @@ main(int argc, char *argv[])
 static SoundProps *
 sound_properties_create(void)
 {
-    SoundProps *retval;
     GtkWidget *table, *vbox, *wtmp, *notebook;
     GtkWidget *frame;
     char *path;
@@ -135,6 +164,7 @@ sound_properties_create(void)
         N_("File to Play")
     };
     gboolean btmp;
+    SoundProps *retval;
 
     retval = g_new0(SoundProps, 1);
 
@@ -147,6 +177,7 @@ sound_properties_create(void)
     retval->capplet = capplet_widget_new();
 #endif
 
+#ifdef HAVE_ESD
     gtk_signal_connect(GTK_OBJECT(retval->capplet), "revert",
                        ui_do_revert, retval);
     gtk_signal_connect(GTK_OBJECT(retval->capplet), "ok",
@@ -281,12 +312,16 @@ sound_properties_create(void)
     gtk_container_add(GTK_CONTAINER(retval->capplet), notebook);
 
     sound_properties_set_sensitivity(NULL, retval);
+#else
+    gtk_container_add(GTK_CONTAINER(retval->capplet), gtk_label_new("This copy of the GNOME control center was not compiled with sound support"));
+#endif
 
     gtk_widget_show_all(retval->capplet);
 
     return retval;
 }
 
+#ifdef HAVE_ESD
 /**** sound_properties_regenerate_ctree
 
       Inputs: 'ctree' - a GtkCTree to put the entries into.
@@ -629,6 +664,14 @@ reload_esd_samples(const char *config_path)
                 int sid;
 
                 g_string_sprintf(tmpstr, "%s/%s", category_name, sample_name);
+
+                /* We need to free up the old sample, because
+                   esd allows multiple samples with the same name,
+                   putting memory to waste. */
+                sid = esd_sample_getid(gnome_sound_connection, tmpstr->str);
+                if(sid >= 0)
+                    esd_sample_free(gnome_sound_connection, sid);
+
                 sid = gnome_sound_sample_load(tmpstr->str, sample_file);
 
                 if(sid < 0)
@@ -662,3 +705,5 @@ reload_all_esd_samples(void)
         g_free(val);
     }
 }
+
+#endif
