@@ -68,7 +68,7 @@ create_exit_dialog (GList *apps)
         char *s;
 
         /* we create the widgets */
-        retval = gnome_dialog_new ("Warning:", GNOME_STOCK_BUTTON_CLOSE, GNOME_STOCK_BUTTON_CANCEL, NULL);
+        retval = gnome_dialog_new ("Warning:",_("Discard all changes"), GNOME_STOCK_BUTTON_CANCEL, NULL);
         gnome_dialog_set_default (GNOME_DIALOG (retval), 1);
         gnome_dialog_set_parent (GNOME_DIALOG (retval), GTK_WINDOW (main_window));
 
@@ -77,8 +77,9 @@ create_exit_dialog (GList *apps)
         right_vbox = gtk_vbox_new (FALSE, 5);
 
         /*...labels, etc */
-        label = gtk_label_new (" The following modules have had changes made,\n but not committed. " \
-                               " If you would like to edit them, please\n click on the appropriate entry.");
+        label = gtk_label_new ("The following modules have had changes made, but not committed.  " \
+                               "If you would like to edit them, please double click on the appropriate entry.");
+        gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
         gtk_label_set_justify (GTK_LABEL (label), GTK_JUSTIFY_LEFT);
 
         /* stolen straight from gnome-message-box (: */
